@@ -2,12 +2,13 @@ import collections
 import gzip
 import hashlib
 import json
+import edgescan.serialization
 import os.path
 import shutil
 import tempfile
 import edgescan.caching
 from typing import Iterator, Any, Optional, Dict
-from edgescan.constants import DEFAULT_API_KEY, DEFAULT_HOST, HOSTS, ASSETS, VULNERABILITIES
+from edgescan.constants import DEFAULT_API_KEY, DEFAULT_HOST, HOSTS, ASSETS, VULNERABILITIES, LICENSES
 from edgescan.data.types.host import Host
 from edgescan.data.types.license import License
 from edgescan.data.types.vulnerability import Vulnerability
@@ -94,7 +95,9 @@ class Client:
             yield row
 
     def _iter_objects(self, resource_type: str) -> Iterator[dict]:
-        if edgescan.caching.is_enabled():
+        if resource_type == LICENSES:
+            yield from self.iter_licenses()
+        elif edgescan.caching.is_enabled():
             yield from self._iter_objects_with_caching(resource_type)
         else:
             yield from self._iter_objects_without_caching(resource_type)
@@ -149,6 +152,23 @@ class Client:
             if row:
                 yield row
 
+    def export_objects(self, resource_type: str, path: str) -> Optional[int]:
+        i = 0
+        with open(path, 'w') as file:
+            for row in self.iter_objects(resource_type):
+                line = edgescan.serialization.to_json(row) + '\n'
+                file.write(line)
+                i += 1
+
+        #: Don't create empty output files.
+        if i == 0:
+            logger.warning("No %s found to write to %s", resource_type, path)
+            os.unlink(path)
+            return None
+
+        logger.info("Wrote %d %s to %s", i, resource_type, path)
+        return i
+
     def count_objects(
             self,
             resource_type: str,
@@ -241,6 +261,9 @@ class Client:
         )
         return _len(assets)
 
+    def export_assets(self, path: str) -> Optional[int]:
+        return self.export_objects(ASSETS, path=path)
+
     def get_host(self, host_id: int) -> Optional[Host]:
         return next(self.iter_hosts(ids=[host_id]), None)
 
@@ -289,6 +312,9 @@ class Client:
 
             yield host
 
+    def export_hosts(self, path: str) -> Optional[int]:
+        return self.export_objects(HOSTS, path=path)
+
     def count_hosts(
             self,
             ids: Optional[INTS] = None,
@@ -389,6 +415,9 @@ class Client:
 
             yield vulnerability
 
+    def export_vulnerabilities(self, path: str) -> Optional[int]:
+        return self.export_objects(VULNERABILITIES, path=path)
+
     def count_vulnerabilities(
             self,
             ids: Optional[INTS] = None,
@@ -453,6 +482,9 @@ class Client:
                 seen.add(active_license['id'])
                 yield active_license
 
+    def export_licenses(self, path: str) -> Optional[int]:
+        return self.export_objects(LICENSES, path=path)
+
     def count_licenses(
             self,
             ids: Optional[INTS] = None,
