@@ -1,3 +1,6 @@
+from click import Group
+
+from edgescan.cli.command_groups.data_exports import data_exports
 from edgescan.cli.command_groups.assets import assets
 from edgescan.cli.command_groups.hosts import hosts
 from edgescan.cli.command_groups.licenses import licenses
@@ -15,10 +18,12 @@ def cli():
 
 
 COMMAND_GROUPS = [
+    data_exports,
     assets,
     hosts,
     licenses,
     vulnerabilities,
 ]
 for command_group in COMMAND_GROUPS:
+    assert isinstance(command_group, Group)
     cli.add_command(command_group)
