@@ -1,13 +1,13 @@
+import json
 from typing import Optional
 
-from click import Context
-
 from edgescan.api.client import Client
 from edgescan.cli.helpers import str_to_strs, str_to_ints, str_to_datetime
 
 import click
 import itertools
 import edgescan.serialization
+import edgescan.tallies
 
 
 @click.group()
@@ -85,6 +85,8 @@ def export_assets(path: str):
 @click.option('--max-create-time')
 @click.option('--min-update-time')
 @click.option('--max-update-time')
+@click.option('--group-by')
+@click.option('--sort-by-key/--sort-by-value', default=True)
 def count_assets(
         asset_ids: Optional[str],
         names: Optional[str],
@@ -92,18 +94,40 @@ def count_assets(
         min_create_time: Optional[str],
         max_create_time: Optional[str],
         min_update_time: Optional[str],
-        max_update_time: Optional[str]):
+        max_update_time: Optional[str],
+        group_by: Optional[str],
+        sort_by_key: bool):
     """
     Count assets.
     """
     api = Client()
-    total = api.count_assets(
-        ids=str_to_ints(asset_ids),
-        names=str_to_strs(names),
-        tags=str_to_strs(tags),
-        min_create_time=str_to_datetime(min_create_time),
-        max_create_time=str_to_datetime(max_create_time),
-        min_update_time=str_to_datetime(min_update_time),
-        max_update_time=str_to_datetime(max_update_time),
-    )
-    click.echo(total)
+
+    if group_by:
+        rows = api.iter_assets(
+            ids=str_to_ints(asset_ids),
+            names=str_to_strs(names),
+            tags=str_to_strs(tags),
+            min_create_time=str_to_datetime(min_create_time),
+            max_create_time=str_to_datetime(max_create_time),
+            min_update_time=str_to_datetime(min_update_time),
+            max_update_time=str_to_datetime(max_update_time),
+        )
+        tally = edgescan.tallies.tally_by(rows, group_by)
+        if sort_by_key:
+            tally = edgescan.tallies.sort_by_key(tally)
+        else:
+            tally = edgescan.tallies.sort_by_value(tally)
+        result = edgescan.serialization.to_json(tally)
+    else:
+        result = api.count_assets(
+            ids=str_to_ints(asset_ids),
+            names=str_to_strs(names),
+            tags=str_to_strs(tags),
+            min_create_time=str_to_datetime(min_create_time),
+            max_create_time=str_to_datetime(max_create_time),
+            min_update_time=str_to_datetime(min_update_time),
+            max_update_time=str_to_datetime(max_update_time),
+        )
+    
+    print(result)
+
