@@ -4,6 +4,7 @@ from edgescan.api.client import Client
 import itertools
 import click
 
+import edgescan.tallies
 import edgescan.serialization
 from edgescan.cli.helpers import str_to_strs, str_to_ints
 
@@ -67,14 +68,35 @@ def export_licenses(path: str):
 @click.option('--license-ids')
 @click.option('--license-names')
 @click.option('--expired/--not-expired', default=None, show_default=True)
-def count_licenses(license_ids: Optional[str], license_names: Optional[str], expired: Optional[bool]):
+@click.option('--group-by')
+@click.option('--sort-by-key/--sort-by-value', default=True)
+def count_licenses(
+    license_ids: Optional[str], 
+    license_names: Optional[str], 
+    expired: Optional[bool],
+    group_by: Optional[str],
+    sort_by_key: bool):
     """
     Count licenses.
     """
     api = Client()
-    total = api.count_licenses(
-        ids=str_to_ints(license_ids),
-        names=str_to_strs(license_names),
-        expired=expired,
-    )
-    click.echo(total)
+
+    if group_by:
+        rows = api.iter_licenses(
+            ids=str_to_ints(license_ids),
+            names=str_to_strs(license_names),
+            expired=expired,
+        )
+        tally = edgescan.tallies.tally_by(rows, group_by)
+        if sort_by_key:
+            tally = edgescan.tallies.sort_by_key(tally)
+        else:
+            tally = edgescan.tallies.sort_by_value(tally)
+        result = edgescan.serialization.to_json(tally)
+    else:
+        result = api.count_licenses(
+            ids=str_to_ints(license_ids),
+            names=str_to_strs(license_names),
+            expired=expired,
+        )
+    print(result)
