@@ -1,6 +1,7 @@
 from typing import Optional
 from edgescan.api.client import Client
 
+import edgescan.tallies
 import itertools
 import edgescan.serialization
 import click
@@ -103,6 +104,8 @@ def export_vulnerabilities(path: str):
 @click.option('--max-create-time')
 @click.option('--min-update-time')
 @click.option('--max-update-time')
+@click.option('--group-by')
+@click.option('--sort-by-key/--sort-by-value', default=True)
 def count_vulnerabilities(
         vulnerability_ids: Optional[str],
         cve_ids: Optional[str],
@@ -115,23 +118,48 @@ def count_vulnerabilities(
         min_create_time: Optional[str],
         max_create_time: Optional[str],
         min_update_time: Optional[str],
-        max_update_time: Optional[str]):
+        max_update_time: Optional[str],
+        group_by: Optional[str],
+        sort_by_key: Optional[bool]):
     """
     Count vulnerabilities.
     """
     api = Client()
-    total = api.count_vulnerabilities(
-        ids=str_to_ints(vulnerability_ids),
-        cve_ids=str_to_strs(cve_ids),
-        host_ids=str_to_ints(host_ids),
-        host_is_alive=host_is_alive,
-        asset_ids=str_to_ints(asset_ids),
-        locations=str_to_strs(locations),
-        include_application_layer_vulnerabilities=include_application_layer_vulnerabilities,
-        include_network_layer_vulnerabilities=include_network_layer_vulnerabilities,
-        min_create_time=str_to_datetime(min_create_time),
-        max_create_time=str_to_datetime(max_create_time),
-        min_update_time=str_to_datetime(min_update_time),
-        max_update_time=str_to_datetime(max_update_time),
-    )
-    click.echo(total)
+
+    if group_by:
+        rows = api.iter_vulnerabilities(
+            ids=str_to_ints(vulnerability_ids),
+            cve_ids=str_to_strs(cve_ids),
+            host_ids=str_to_ints(host_ids),
+            host_is_alive=host_is_alive,
+            asset_ids=str_to_ints(asset_ids),
+            locations=str_to_strs(locations),
+            include_application_layer_vulnerabilities=include_application_layer_vulnerabilities,
+            include_network_layer_vulnerabilities=include_network_layer_vulnerabilities,
+            min_create_time=str_to_datetime(min_create_time),
+            max_create_time=str_to_datetime(max_create_time),
+            min_update_time=str_to_datetime(min_update_time),
+            max_update_time=str_to_datetime(max_update_time),
+        )
+        tally = edgescan.tallies.tally_by(rows, group_by)
+        if sort_by_key:
+            tally = edgescan.tallies.sort_by_key(tally)
+        else:
+            tally = edgescan.tallies.sort_by_value(tally)
+        result = edgescan.serialization.to_json(tally)
+    else:
+        result = api.count_vulnerabilities(
+            ids=str_to_ints(vulnerability_ids),
+            cve_ids=str_to_strs(cve_ids),
+            host_ids=str_to_ints(host_ids),
+            host_is_alive=host_is_alive,
+            asset_ids=str_to_ints(asset_ids),
+            locations=str_to_strs(locations),
+            include_application_layer_vulnerabilities=include_application_layer_vulnerabilities,
+            include_network_layer_vulnerabilities=include_network_layer_vulnerabilities,
+            min_create_time=str_to_datetime(min_create_time),
+            max_create_time=str_to_datetime(max_create_time),
+            min_update_time=str_to_datetime(min_update_time),
+            max_update_time=str_to_datetime(max_update_time),
+        )
+    print(result)
