@@ -13,3 +13,12 @@ def dict_to_dataclass(data: Any, cls: Any) -> Any:
     fields = {f.name for f in fields}
     data = dict(((k, v) for (k, v) in data.items() if k in fields))
     return cls(**data)
+
+
+def is_iterable(value: str) -> bool:
+    try:
+        iter(value)
+    except TypeError:
+        return False
+    else:
+        return True
